ImagePreviewPage class

A full-screen image preview page with pan and zoom support.

Usage:

Navigator.push(
  context,
  MaterialPageRoute(
    builder: (_) => ImagePreviewPage(
      imageUrls: ['url1', 'url2'],
      initialIndex: 0,
    ),
  ),
);
Inheritance

Constructors

ImagePreviewPage({required List<String> imageUrls, required int initialIndex, String titleBuilder(int index, int total)?, String? appBarTitle, Key? key})
const

Properties

appBarTitle String?
Static app bar title. If provided along with titleBuilder, titleBuilder takes precedence.
final
hashCode int
The hash code for this object.
no setterinherited
imageUrls List<String>
List of image URLs to display
final
initialIndex int
The initial page index to display
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
titleBuilder String Function(int index, int total)?
Custom title builder for the app bar. If not provided, uses default format
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<ImagePreviewPage>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited