NumberFormatter class

Number formatting utilities for currency, decimals, and file sizes.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

formatCash(num amount, {String locale = 'en_KE', String symbol = '', int decimalDigits = 0, String? customSymbol}) String
Format currency amount
formatFileSize(int bytes) String
Format file size in human readable format
roundToDecimalPlaces(double value, int fractionalDigits) double
Round to decimal places
truncateToDecimalPlaces(double value, int fractionalDigits) double
Truncate to decimal places