PRFErrorType enum

Types of errors that can occur in the application.

Inheritance
Available extensions

Values

network → const PRFErrorType

Network connectivity issues

authentication → const PRFErrorType

Authentication errors (invalid credentials, expired tokens)

authorization → const PRFErrorType

Authorization errors (insufficient permissions)

validation → const PRFErrorType

Input validation errors

notFound → const PRFErrorType

Resource not found

server → const PRFErrorType

Server-side errors (5xx)

timeout → const PRFErrorType

Request timeout

cancelled → const PRFErrorType

Request was cancelled

unknown → const PRFErrorType

Unknown or unclassified error

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PRFErrorType>
A constant List of the values in this enum, in order of their declaration.