Centralized semantic status colors used by theme extensions.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- activeGlow → const Color
- errorBackgroundDark → const Color
- errorMainDark → const Color
- infoBackgroundDark → const Color
- initiatedBackgroundDark → const Color
- initiatedBackgroundLight → const Color
- inProgressBackgroundDark → const Color
- inProgressBackgroundLight → const Color
- pendingBackgroundDark → const Color
- pendingBackgroundLight → const Color
- successBackgroundDark → const Color
- warningBackgroundDark → const Color