StringFormatter class
String formatting utilities.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
generateRandomString(
int length, {bool includeNumbers = true, bool includeSymbols = false}) → String - Generate random string
-
getFileName(
String path) → String - Get file name from a path
-
getUserNameInitials(
String userName, {int maxInitials = 2}) → String - Get initials from a user name