Debouncer class
A utility class for debouncing function calls.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isPending → bool
-
Returns true if there's a pending action.
no setter
- milliseconds → int
-
The delay in milliseconds before executing the debounced function.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cancel(
) → void - Cancels any pending debounced action without executing it.
-
dispose(
) → void - Disposes of the debouncer and cancels any pending actions.
-
flush(
) → void - Immediately executes any pending action and cancels the timer.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
VoidCallback action) → void - Executes the action after the debounce delay.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited