PRFCarouselItem class
A media item for the carousel.
Points at an image or video url. Videos are only rendered when the carousel is given a PRFMediaCarousel.videoBuilder.
Example:
PRFCarouselItem(url: photo.url, isVideo: false)
PRFCarouselItem(url: video.url, isVideo: true)
Constructors
- PRFCarouselItem({required String url, required bool isVideo, String? id})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
Optional stable identifier for the item.
final
- isVideo → bool
-
When true the item is treated as a video.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → String
-
Media URL.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited